@@ -27,6 +27,12 @@ def compute_args():
         action="store_true",
         help="full trace",
     )
+    my_parser.add_argument(
+        "-n",
+        "--nocolor",
+        action="store_true",
+        help="disable colors in sysout",
+    )
     my_parser.add_argument(
         "-q",
         "--fast",
@@ -50,6 +56,7 @@ def compute_args():
         metavar="keyword",
         action="store",
         type=str,
+        nargs="+", 
         help="search in logs 'keyword' from all branches",
     )
     my_group.add_argument(
@@ -72,6 +79,7 @@ def compute_args():
         action="store_true",
         help="display local only branches, local branches with push available, stashes, and number of untracked/unstaged/uncommited files",
     )
+
     my_group.add_argument(
         "-p",
         "--prune",
