@@ -8,26 +8,25 @@ import colorama
 
 
 def print_resume_list(list_to_print, message):
-    colorama.init()
     """
     print list summary
     """
     if len(list_to_print) > 0:
         print("")
         print(
-            colored(
+            my_colored(
                 message + " : ",
                 "green",
             )
         )
         print(
-            colored(
+            my_colored(
                 "\n".join(map(str, list_to_print)),
                 "yellow",
             )
         )
         print(
-            colored(
+            my_colored(
                 "total : " + str(len(list_to_print)),
                 "green",
             )
@@ -38,13 +37,12 @@ def print_resume_map(dict_to_print, message):
     """
     print dict summary
     """
-    colorama.init()
     if len(dict_to_print) > 0:
         print("")
-        print(colored(message + " : ", "green"))
+        print(my_colored(message + " : ", "green"))
         for key in dict_to_print:
             print(
-                colored(
+                my_colored(
                     key
                     + " --> "
                     + str(dict_to_print[key])
@@ -53,7 +51,7 @@ def print_resume_map(dict_to_print, message):
                 )
             )
         print(
-            colored(
+            my_colored(
                 "total : "
                 + str(len(dict_to_print))
                 + " --> "
@@ -76,21 +74,23 @@ def print_y(message):
     """
     print yellow message
     """
-    colorama.init()
-    print(colored(message, "yellow"))
+    print(my_colored(message, "yellow"))
 
 
 def print_g(message):
     """
     print green message
     """
-    colorama.init()
-    print(colored(message, "green"))
+    print(my_colored(message, "green"))
 
 
 def print_r(message):
     """
     print red message
     """
-    colorama.init()
-    print(colored(message, "red"))
+    print(my_colored(message, "red"))
+
+def my_colored(message,color):
+    if compute_args().nocolor:
+        return message
+    return colored(message, color)       
